DELETE: chat.json
-----------------

Delete chat means that one of participants want to exit from conversation. Therefore all undelivered messages should be 
delivered and chat should completely removed from SFChat server.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Request
   Response
